summaryrefslogtreecommitdiff
path: root/nsswitch/libwbclient/wbc_idmap.c
diff options
context:
space:
mode:
authorMichael Adam <obnox@samba.org>2009-01-22 13:39:33 +0100
committerMichael Adam <obnox@samba.org>2010-08-14 02:10:31 +0200
commitec33a624a395d6108e47a4eef9430626ec83b314 (patch)
tree582ddef736e6c370c6b1fbbccfe36386fa1a20df /nsswitch/libwbclient/wbc_idmap.c
parente09a269bcc76be2101a285c0466f7fffa74366ac (diff)
downloadsamba-ec33a624a395d6108e47a4eef9430626ec83b314.tar.gz
samba-ec33a624a395d6108e47a4eef9430626ec83b314.tar.bz2
samba-ec33a624a395d6108e47a4eef9430626ec83b314.zip
libwbclient: unimplement wbcSetGidHwm()
Michael
Diffstat (limited to 'nsswitch/libwbclient/wbc_idmap.c')
-rw-r--r--nsswitch/libwbclient/wbc_idmap.c23
1 files changed, 2 insertions, 21 deletions
diff --git a/nsswitch/libwbclient/wbc_idmap.c b/nsswitch/libwbclient/wbc_idmap.c
index dc9bf36369..232c1ca71a 100644
--- a/nsswitch/libwbclient/wbc_idmap.c
+++ b/nsswitch/libwbclient/wbc_idmap.c
@@ -425,27 +425,8 @@ wbcErr wbcSetUidHwm(uid_t uid_hwm)
return WBC_ERR_NOT_IMPLEMENTED;
}
/* Set the highwater mark for allocated gids. */
wbcErr wbcSetGidHwm(gid_t gid_hwm)
{
- struct winbindd_request request;
- struct winbindd_response response;
- wbcErr wbc_status = WBC_ERR_UNKNOWN_FAILURE;
-
- /* Initialise request */
-
- ZERO_STRUCT(request);
- ZERO_STRUCT(response);
-
- /* Make request */
-
- request.data.dual_idmapset.id = gid_hwm;
- request.data.dual_idmapset.type = _ID_TYPE_GID;
-
- wbc_status = wbcRequestResponsePriv(WINBINDD_SET_HWM,
- &request, &response);
- BAIL_ON_WBC_ERROR(wbc_status);
-
- done:
- return wbc_status;
+ return WBC_ERR_NOT_IMPLEMENTED;
}
@@ -425,27 +425,8 @@ wbcErr wbcSetUidHwm(uid_t uid_hwm)
return WBC_ERR_NOT_IMPLEMENTED;
}
-/* Set the highwater mark for allocated gids. */
+/* Set the highwater mark for allocated gids - not implemented any more */
wbcErr wbcSetGidHwm(gid_t gid_hwm)
{